@@ -35,7 +35,7 @@ AudioStream()
 
 const char* BayonneAudio::getVoicelib(const char *lib)
 {
-	char buf[256];
+	char buf[MAX_PATHNAME];
 	char *f, *l;
 
 	if(!lib)
@@ -75,7 +75,7 @@ const char *BayonneAudio::getFilename(const char *name, bool write)
 {
 	const char *ext;
 	const char *prefix = NULL;
-	char *buf = filename;
+	char buf[MAX_PATHNAME];
 	char *cp;
 	size_t max = sizeof(filename);
 
@@ -101,7 +101,7 @@ const char *BayonneAudio::getFilename(const char *name, bool write)
 			return name;
 		
 		snprintf(buf, max, "%s%s", name, extension);
-		return buf;
+		goto finish;
 	}
 
 	if(!strnicmp(name, "tmp:", 4))
@@ -127,7 +127,7 @@ const char *BayonneAudio::getFilename(const char *name, bool write)
 			ext = extension;
 		
 		snprintf(buf, max, "%s/%s%s", prefix, name, ext);
-		return buf; 
+		goto finish; 
 	}
 
 	if(write)
@@ -142,8 +142,8 @@ const char *BayonneAudio::getFilename(const char *name, bool write)
 		else
 			ext = libext;
 
-		snprintf(buf, max, "%s/%s/%s%s", path_prompts, voicelib, name, ext);
-		return buf;
+		snprintf(filename, max, "%s/%s/%s%s", path_prompts, voicelib, name, ext);
+		return filename;
 	}
 
 	ext = strrchr(name, '.');
@@ -155,8 +155,14 @@ const char *BayonneAudio::getFilename(const char *name, bool write)
 	snprintf(buf, max, "%s/none/%s%s", path_prompts, name, ext);
 	cp = strrchr(buf, ':');
 	if(cp)
-		*cp = 0;
-	return buf;
+		*cp = '/';
+
+finish:
+	if(buf[0] == '/' || buf[1] == ':')
+		setString(filename, max, buf);
+	else
+		snprintf(filename, max, "%s/%s", server->getLast("prefix"), buf);
+	return filename;
 }
 
 void BayonneAudio::play(const char **files, Mode m)
@@ -166,20 +172,20 @@ void BayonneAudio::play(const char **files, Mode m)
 	if(isOpen())
 		AudioStream::close();
 
-	list = NULL;
-
 	if(!fn)
 		return;
 
+	list = files;
 	mode = m;
 	AudioStream::open(fn, m, framing);
 	if(!isOpen())
+	{
+		list = NULL;
 		return;
+	}
 
 	if(offset)
 		position(offset);
-
-	list = files;
 }
 
 char *BayonneAudio::getContinuation(void)
