@@ -131,7 +131,7 @@ void liveConfig(void)
 	char path[256];
 	char lang[32];
 	const char *env;
-	char *p;
+	char *p, *sp, *tok;
 	const char *cp;
 	unsigned timeslots = atoi(keyengine.getLast("timeslots"));
 
@@ -214,6 +214,27 @@ void liveConfig(void)
 		keypaths.setValue("tmpfs", path);
 
 #endif
+        sp = (char *)keyserver.getLast("definitions");
+        if(sp && !stricmp(sp, "none"))
+                sp = NULL;
+
+        if(sp && !*sp)
+                sp = NULL;
+        if(sp)
+                cp = strtok_r(sp, " ,;:\t", &tok);
+        else
+                cp = NULL;
+
+        while(cp)
+        {
+                if(strrchr(cp, '.'))
+                        setString(path, sizeof(path), cp);
+                else
+                        snprintf(path, sizeof(path), "%s.def", cp);
+                runtime.setValue("definitions", path);
+                cp = strtok_r(NULL, " ,;:\t", &tok);
+        }
+
 	cp = keyoptions.getLast("prefix");
 #ifdef	WIN32
 	if(Bayonne::provision_test)
